@@ -216,6 +216,9 @@ create_tree_view (EelMimeApplicationChooser *chooser)
 				    GDK_TYPE_PIXBUF,
 				    G_TYPE_STRING,
 				    G_TYPE_STRING);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+					      COLUMN_NAME,
+					      GTK_SORT_ASCENDING);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview),
 				 GTK_TREE_MODEL (store));
 	chooser->details->model = store;
@@ -518,6 +521,7 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 		chooser->details->mime_type = 
 			g_strdup_printf ("application/x-extension-%s", 
 					 extension);
+		/* the %s here is a file extension */
 		chooser->details->mime_description = 
 			g_strdup_printf (_("%s document"), extension);
 		
@@ -535,6 +539,7 @@ set_uri_and_mime_type (EelMimeApplicationChooser *chooser,
 		chooser->details->mime_description = description;
 	}
 
+	/* first %s is filename, second %s is mime-type description */
 	label = g_strdup_printf (_("Select an application to open <i>%s</i> and others of type \"%s\""), name, chooser->details->mime_description);
 	
 	gtk_label_set_markup (GTK_LABEL (chooser->details->label), label);
